/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * This file is available under and governed by the GNU General Public
 * License version 2 only, as published by the Free Software Foundation.
 * However, the following notice accompanied the original version of this
 * file:
 *
 * Written by Doug Lea with assistance from members of JCP JSR-166
 * Expert Group and released to the public domain, as explained at
 * http://creativecommons.org/publicdomain/zero/1.0/
 */


package java.util.concurrent.atomic;

import java.lang.invoke.VarHandle;

/**
 * An {@code int} value that may be updated atomically.  See the
 * {@link java.lang.invoke.VarHandle VarHandle} specification for descriptions of the properties
 * of atomic accesses. An {@code AtomicInteger} is used in
 * applications such as atomically incremented counters, and cannot be
 * used as a replacement for an {@link java.lang.Integer}. However,
 * this class does extend {@code Number} to allow uniform access by
 * tools and utilities that deal with numerically-based classes.
 *
 * @since 1.5
 * @author Doug Lea
 */

@SuppressWarnings({"unchecked", "deprecation", "all"})
public class AtomicInteger extends java.lang.Number implements java.io.Serializable {

/**
 * Creates a new AtomicInteger with the given initial value.
 *
 * @param initialValue the initial value
 */

public AtomicInteger(int initialValue) { throw new RuntimeException("Stub!"); }

/**
 * Creates a new AtomicInteger with initial value {@code 0}.
 */

public AtomicInteger() { throw new RuntimeException("Stub!"); }

/**
 * Returns the current value,
 * with memory effects as specified by {@link java.lang.invoke.VarHandle#getVolatile VarHandle#getVolatile}.
 *
 * @return the current value
 */

public final int get() { throw new RuntimeException("Stub!"); }

/**
 * Sets the value to {@code newValue},
 * with memory effects as specified by {@link java.lang.invoke.VarHandle#setVolatile VarHandle#setVolatile}.
 *
 * @param newValue the new value
 */

public final void set(int newValue) { throw new RuntimeException("Stub!"); }

/**
 * Sets the value to {@code newValue},
 * with memory effects as specified by {@link java.lang.invoke.VarHandle#setRelease VarHandle#setRelease}.
 *
 * @param newValue the new value
 * @since 1.6
 */

public final void lazySet(int newValue) { throw new RuntimeException("Stub!"); }

/**
 * Atomically sets the value to {@code newValue} and returns the old value,
 * with memory effects as specified by {@link java.lang.invoke.VarHandle#getAndSet VarHandle#getAndSet}.
 *
 * @param newValue the new value
 * @return the previous value
 */

public final int getAndSet(int newValue) { throw new RuntimeException("Stub!"); }

/**
 * Atomically sets the value to {@code newValue}
 * if the current value {@code == expectedValue},
 * with memory effects as specified by {@link java.lang.invoke.VarHandle#compareAndSet VarHandle#compareAndSet}.
 *
 * @param expectedValue the expected value
 * @param newValue the new value
 * @return {@code true} if successful. False return indicates that
 * the actual value was not equal to the expected value.
 */

public final boolean compareAndSet(int expectedValue, int newValue) { throw new RuntimeException("Stub!"); }

/**
 * Possibly atomically sets the value to {@code newValue}
 * if the current value {@code == expectedValue},
 * with memory effects as specified by {@link java.lang.invoke.VarHandle#weakCompareAndSetPlain VarHandle#weakCompareAndSetPlain}.
 *
 * @deprecated This method has plain memory effects but the method
 * name implies volatile memory effects (see methods such as
 * {@link #compareAndExchange} and {@link #compareAndSet}).  To avoid
 * confusion over plain or volatile memory effects it is recommended that
 * the method {@link #weakCompareAndSetPlain} be used instead.
 *
 * @param expectedValue the expected value
 * @param newValue the new value
 * @return {@code true} if successful
 * @see #weakCompareAndSetPlain
 */

@Deprecated
public final boolean weakCompareAndSet(int expectedValue, int newValue) { throw new RuntimeException("Stub!"); }

/**
 * Possibly atomically sets the value to {@code newValue}
 * if the current value {@code == expectedValue},
 * with memory effects as specified by {@link java.lang.invoke.VarHandle#weakCompareAndSetPlain VarHandle#weakCompareAndSetPlain}.
 *
 * @param expectedValue the expected value
 * @param newValue the new value
 * @return {@code true} if successful
 * @since 9
 */

public final boolean weakCompareAndSetPlain(int expectedValue, int newValue) { throw new RuntimeException("Stub!"); }

/**
 * Atomically increments the current value,
 * with memory effects as specified by {@link java.lang.invoke.VarHandle#getAndAdd VarHandle#getAndAdd}.
 *
 * <p>Equivalent to {@code getAndAdd(1)}.
 *
 * @return the previous value
 */

public final int getAndIncrement() { throw new RuntimeException("Stub!"); }

/**
 * Atomically decrements the current value,
 * with memory effects as specified by {@link java.lang.invoke.VarHandle#getAndAdd VarHandle#getAndAdd}.
 *
 * <p>Equivalent to {@code getAndAdd(-1)}.
 *
 * @return the previous value
 */

public final int getAndDecrement() { throw new RuntimeException("Stub!"); }

/**
 * Atomically adds the given value to the current value,
 * with memory effects as specified by {@link java.lang.invoke.VarHandle#getAndAdd VarHandle#getAndAdd}.
 *
 * @param delta the value to add
 * @return the previous value
 */

public final int getAndAdd(int delta) { throw new RuntimeException("Stub!"); }

/**
 * Atomically increments the current value,
 * with memory effects as specified by {@link java.lang.invoke.VarHandle#getAndAdd VarHandle#getAndAdd}.
 *
 * <p>Equivalent to {@code addAndGet(1)}.
 *
 * @return the updated value
 */

public final int incrementAndGet() { throw new RuntimeException("Stub!"); }

/**
 * Atomically decrements the current value,
 * with memory effects as specified by {@link java.lang.invoke.VarHandle#getAndAdd VarHandle#getAndAdd}.
 *
 * <p>Equivalent to {@code addAndGet(-1)}.
 *
 * @return the updated value
 */

public final int decrementAndGet() { throw new RuntimeException("Stub!"); }

/**
 * Atomically adds the given value to the current value,
 * with memory effects as specified by {@link java.lang.invoke.VarHandle#getAndAdd VarHandle#getAndAdd}.
 *
 * @param delta the value to add
 * @return the updated value
 */

public final int addAndGet(int delta) { throw new RuntimeException("Stub!"); }

/**
 * Atomically updates (with memory effects as specified by {@link java.lang.invoke.VarHandle#compareAndSet  }) the current value with the results of
 * applying the given function, returning the previous value. The
 * function should be side-effect-free, since it may be re-applied
 * when attempted updates fail due to contention among threads.
 *
 * @param updateFunction a side-effect-free function
 * @return the previous value
 * @since 1.8
 */

public final int getAndUpdate(java.util.function.IntUnaryOperator updateFunction) { throw new RuntimeException("Stub!"); }

/**
 * Atomically updates (with memory effects as specified by {@link java.lang.invoke.VarHandle#compareAndSet  }) the current value with the results of
 * applying the given function, returning the updated value. The
 * function should be side-effect-free, since it may be re-applied
 * when attempted updates fail due to contention among threads.
 *
 * @param updateFunction a side-effect-free function
 * @return the updated value
 * @since 1.8
 */

public final int updateAndGet(java.util.function.IntUnaryOperator updateFunction) { throw new RuntimeException("Stub!"); }

/**
 * Atomically updates (with memory effects as specified by {@link java.lang.invoke.VarHandle#compareAndSet  }) the current value with the results of
 * applying the given function to the current and given values,
 * returning the previous value. The function should be
 * side-effect-free, since it may be re-applied when attempted
 * updates fail due to contention among threads.  The function is
 * applied with the current value as its first argument, and the
 * given update as the second argument.
 *
 * @param x the update value
 * @param accumulatorFunction a side-effect-free function of two arguments
 * @return the previous value
 * @since 1.8
 */

public final int getAndAccumulate(int x, java.util.function.IntBinaryOperator accumulatorFunction) { throw new RuntimeException("Stub!"); }

/**
 * Atomically updates (with memory effects as specified by {@link java.lang.invoke.VarHandle#compareAndSet  }) the current value with the results of
 * applying the given function to the current and given values,
 * returning the updated value. The function should be
 * side-effect-free, since it may be re-applied when attempted
 * updates fail due to contention among threads.  The function is
 * applied with the current value as its first argument, and the
 * given update as the second argument.
 *
 * @param x the update value
 * @param accumulatorFunction a side-effect-free function of two arguments
 * @return the updated value
 * @since 1.8
 */

public final int accumulateAndGet(int x, java.util.function.IntBinaryOperator accumulatorFunction) { throw new RuntimeException("Stub!"); }

/**
 * Returns the String representation of the current value.
 * @return the String representation of the current value
 */

public java.lang.String toString() { throw new RuntimeException("Stub!"); }

/**
 * Returns the current value of this {@code AtomicInteger} as an
 * {@code int},
 * with memory effects as specified by {@link java.lang.invoke.VarHandle#getVolatile VarHandle#getVolatile}.
 *
 * Equivalent to {@link #get()}.
 */

public int intValue() { throw new RuntimeException("Stub!"); }

/**
 * Returns the current value of this {@code AtomicInteger} as a
 * {@code long} after a widening primitive conversion,
 * with memory effects as specified by {@link java.lang.invoke.VarHandle#getVolatile VarHandle#getVolatile}.
 * @jls 5.1.2 Widening Primitive Conversions
 */

public long longValue() { throw new RuntimeException("Stub!"); }

/**
 * Returns the current value of this {@code AtomicInteger} as a
 * {@code float} after a widening primitive conversion,
 * with memory effects as specified by {@link java.lang.invoke.VarHandle#getVolatile VarHandle#getVolatile}.
 * @jls 5.1.2 Widening Primitive Conversions
 */

public float floatValue() { throw new RuntimeException("Stub!"); }

/**
 * Returns the current value of this {@code AtomicInteger} as a
 * {@code double} after a widening primitive conversion,
 * with memory effects as specified by {@link java.lang.invoke.VarHandle#getVolatile VarHandle#getVolatile}.
 * @jls 5.1.2 Widening Primitive Conversions
 */

public double doubleValue() { throw new RuntimeException("Stub!"); }

/**
 * Returns the current value, with memory semantics of reading as
 * if the variable was declared non-{@code volatile}.
 *
 * @return the value
 * @since 9
 */

public final int getPlain() { throw new RuntimeException("Stub!"); }

/**
 * Sets the value to {@code newValue}, with memory semantics
 * of setting as if the variable was declared non-{@code volatile}
 * and non-{@code final}.
 *
 * @param newValue the new value
 * @since 9
 */

public final void setPlain(int newValue) { throw new RuntimeException("Stub!"); }

/**
 * Returns the current value,
 * with memory effects as specified by {@link java.lang.invoke.VarHandle#getOpaque VarHandle#getOpaque}.
 *
 * @return the value
 * @since 9
 */

public final int getOpaque() { throw new RuntimeException("Stub!"); }

/**
 * Sets the value to {@code newValue},
 * with memory effects as specified by {@link java.lang.invoke.VarHandle#setOpaque VarHandle#setOpaque}.
 *
 * @param newValue the new value
 * @since 9
 */

public final void setOpaque(int newValue) { throw new RuntimeException("Stub!"); }

/**
 * Returns the current value,
 * with memory effects as specified by {@link java.lang.invoke.VarHandle#getAcquire VarHandle#getAcquire}.
 *
 * @return the value
 * @since 9
 */

public final int getAcquire() { throw new RuntimeException("Stub!"); }

/**
 * Sets the value to {@code newValue},
 * with memory effects as specified by {@link java.lang.invoke.VarHandle#setRelease VarHandle#setRelease}.
 *
 * @param newValue the new value
 * @since 9
 */

public final void setRelease(int newValue) { throw new RuntimeException("Stub!"); }

/**
 * Atomically sets the value to {@code newValue} if the current value,
 * referred to as the <em>witness value</em>, {@code == expectedValue},
 * with memory effects as specified by
 * {@link java.lang.invoke.VarHandle#compareAndExchange VarHandle#compareAndExchange}.
 *
 * @param expectedValue the expected value
 * @param newValue the new value
 * @return the witness value, which will be the same as the
 * expected value if successful
 * @since 9
 */

public final int compareAndExchange(int expectedValue, int newValue) { throw new RuntimeException("Stub!"); }

/**
 * Atomically sets the value to {@code newValue} if the current value,
 * referred to as the <em>witness value</em>, {@code == expectedValue},
 * with memory effects as specified by
 * {@link java.lang.invoke.VarHandle#compareAndExchangeAcquire VarHandle#compareAndExchangeAcquire}.
 *
 * @param expectedValue the expected value
 * @param newValue the new value
 * @return the witness value, which will be the same as the
 * expected value if successful
 * @since 9
 */

public final int compareAndExchangeAcquire(int expectedValue, int newValue) { throw new RuntimeException("Stub!"); }

/**
 * Atomically sets the value to {@code newValue} if the current value,
 * referred to as the <em>witness value</em>, {@code == expectedValue},
 * with memory effects as specified by
 * {@link java.lang.invoke.VarHandle#compareAndExchangeRelease VarHandle#compareAndExchangeRelease}.
 *
 * @param expectedValue the expected value
 * @param newValue the new value
 * @return the witness value, which will be the same as the
 * expected value if successful
 * @since 9
 */

public final int compareAndExchangeRelease(int expectedValue, int newValue) { throw new RuntimeException("Stub!"); }

/**
 * Possibly atomically sets the value to {@code newValue} if
 * the current value {@code == expectedValue},
 * with memory effects as specified by
 * {@link java.lang.invoke.VarHandle#weakCompareAndSet VarHandle#weakCompareAndSet}.
 *
 * @param expectedValue the expected value
 * @param newValue the new value
 * @return {@code true} if successful
 * @since 9
 */

public final boolean weakCompareAndSetVolatile(int expectedValue, int newValue) { throw new RuntimeException("Stub!"); }

/**
 * Possibly atomically sets the value to {@code newValue} if
 * the current value {@code == expectedValue},
 * with memory effects as specified by
 * {@link java.lang.invoke.VarHandle#weakCompareAndSetAcquire VarHandle#weakCompareAndSetAcquire}.
 *
 * @param expectedValue the expected value
 * @param newValue the new value
 * @return {@code true} if successful
 * @since 9
 */

public final boolean weakCompareAndSetAcquire(int expectedValue, int newValue) { throw new RuntimeException("Stub!"); }

/**
 * Possibly atomically sets the value to {@code newValue} if
 * the current value {@code == expectedValue},
 * with memory effects as specified by
 * {@link java.lang.invoke.VarHandle#weakCompareAndSetRelease VarHandle#weakCompareAndSetRelease}.
 *
 * @param expectedValue the expected value
 * @param newValue the new value
 * @return {@code true} if successful
 * @since 9
 */

public final boolean weakCompareAndSetRelease(int expectedValue, int newValue) { throw new RuntimeException("Stub!"); }
}

